#
# spec file for package clang-extract
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clang-extract
Version:        0~20240731.94276b7
Release:        1.1
Summary:        A tool to extract code content from source files
License:        Apache-2.0 WITH LLVM-exception AND NCSA
URL:            https://github.com/SUSE/clang-extract
Source:         %{name}-%{version}.tar.xz
BuildRequires:  clang
BuildRequires:  clang-devel
BuildRequires:  clang-tools
BuildRequires:  cmake
BuildRequires:  libelf-devel
# At least 16 is needed but 18 has some fixes that we like.
# Leap 15.6 has only 17.
BuildRequires:  llvm-devel >= 17
BuildRequires:  meson
BuildRequires:  ninja

%description
A tool to extract code content from source files using the clang and LLVM infrastructure.

%prep
%autosetup -p1

%build
%meson --native-file ce-native.ini
%meson_build

%install
%meson_install

%check
%meson_test

%files
%license LICENSE.TXT
%doc README.md
%{_bindir}/ce-inline
%{_bindir}/clang-extract

%changelog
* Thu Aug  1 2024 mvetter@suse.com
- Update to version 0~20240731.94276b7:
  * Remove functions body from Closure.hh
  * Analyze Decls with same BeginLoc
  * LLVMMisc.cpp: Check if identifier exists in SymbolTable
  * Fix failing testcase if system compiler is gcc-14
* Mon Jul 29 2024 mvetter@suse.com
- Update to version 0~20240726.4309abc:
  * Fix closure missing TypedefDecl because not being referenced by type
* Tue Jul 23 2024 mvetter@suse.com
- Update to version 0~20240722.a998e91:
  * Fix clang-extract discarding struct-partial definition in nested record
  * Add (failing) testcase
  * Fix clang-extract dropping complete definition of struct when a copy is necessary
  * Fix struct being redefined if defined in variable type
  * Extend parent RecordDecl analysis for EnumDecls
  * Remove redundant leftmost decl from closure
  * Avoid adding every previous decl of a global variable
  * Force TagDecl as needing fulldefiniton if is a return type of a function
  * Deference pointer types when searching for decomposed typedef-struct
  * Analyze CleanupAttr
  * Avoid adding previous declarations of typedefs into closure
  * SymbolExternalizer: Check KLP_ macros only if there was externzalized syms
* Mon Jul 22 2024 mvetter@suse.com
- Update to version 0~20240721.9b2dfb6:
  * Remove the EnumConstantTable
* Sat Jul 20 2024 mvetter@suse.com
- Update to version 0~20240720.6054fa3:
  * Fix nested struct being discarded if parent struct is flagged as partial
  * Fix __builtin_convertvector escaping the closure
  * Fix dropped attributes from vector types
* Mon Jul 15 2024 mvetter@suse.com
- Update to version 0~20240714.17e3908:
  * Fix location comment of LateExternalized variables
  * Implement first effective use in SymbolExternalizer
  * FunctionDepsFinder: Factor out closure logic
* Fri Jul 12 2024 mvetter@suse.com
- Update to version 0~20240711.74a63c6:
  * Implement Late Externalization for STRONG externalization type
  * Check the TagDecl in TypedefNameDecl for extra attributes
  * Github CI: Drop llvm-16, enable llvm-17 and 18
  * Add logic to get the system's gcc headers install folder
  * Undefine noinline macro if conflicts with AST dump
  * Store ASTUnit in PrettyPrint instead of SourceManager
* Fri Jul  5 2024 mvetter@suse.com
- Update to version 0~20240704.16ab0bf:
  * IncludeTree: Always check for full name of the header
  * Remove unused python packages
- Remove unneeded python BR
* Thu Jul  4 2024 mvetter@suse.com
- Update to version 0~20240704.d14d609:
  * libcextract: ArgvParser: Change path to /usr/lib on x86 32bit
  * testsuite: attr: Use esp for current stack point on x86 32bit
* Thu Jul  4 2024 Michael Vetter <mvetter@suse.com>
- Put version requirement on llvm-devel
* Thu Jul  4 2024 mvetter@suse.com
- Update to version 0~20240703.0b3e33c:
  * Initialize OutputFunctionPrototypeHeader
* Tue Jul  2 2024 mvetter@suse.com
- Update to version 0~20240702.cbdca46:
  * README.md: Remove dependency on python311-subprocess-tee
  * testsuite: attr: Adapt testcase to be executed on ppc64le
- Remove BR python3-subprocess-tee
* Tue Jul  2 2024 mvetter@suse.com
- Update to version 0~20240702.1f3826f:
  * testsuite/attr: Skip tests on s390x
  * libtest: Add special dg-skip-on-archs option
* Fri Jun 28 2024 mvetter@suse.com
- Update to version 0~20240627.52683d1:
  * testsuite: Adapt registers usage to aarch64
  * SymbolExternalizer: Refactor Get_Range_Of_Identifier
  * SymbolExternalizer: Rewrite to use RecursiveASTVisitor
  * SymbolExternalizer: Reduce indentation of _Externalize_Symbol
  * SymbolExternalizer: Simplify Externalize_Symbols
* Thu Jun 20 2024 Michael Vetter <mvetter@suse.com>
- Initial package of clang-extract git f7c935 for openSUSE
